==> discord-chatbot-deskent-1.3.1.tar.gz: discord-chatbot-deskent-1.3.1/README.md <==
1. Установка и настройка:
    1. В файле .env нужно добавить токен от телеграм бота в поле
    TELEBOT_TOKEN="telegram_bot_token"

    2. свой ID телеграма в поле
    ADMIN="123456789"
    свой ID телеграма можно узнать в боте https://t.me/userinfobot

    3. и дискорд токен для парсинга в поле
    PARSING_TOKEN="discord_parsing_token"

2. Бот запускается командой python main.py локально или на сервере пользователя.
Для работы необходима версия python 3.8 или выше
3. Бот является телеграм-ботом, через который осуществляется запуск и управление.
4. Токены для дискорда хранятся в файле tokens.txt
5. Фразы хранятся в файле vocabulary.txt
   1. Прокси хранятся в файле proxies.txt в формате 123.123.123.123:12345 (address:port)
      В файле .env находятся настройки бота:
        TELEBOT_TOKEN="telegram_bot_token" - токен от телеграм бота, для управления
        MESSAGES_COUNT=1000 - количество сообщений для парсинга
        MIN_PAUSE=1 - минимальное значение для паузы между сообщениями
        MAX_PAUSE=3600 - максимальное значение для паузы между сообщениями
        ADMIN="123456789" - телеграм id пользователя, которому будет доступен телеграм бот
        PARSING_TOKEN="token_for_chat_parsing" - токен дискорда для парсинга фраз
     Настройки для имен файлов:
        VOCABULARY_PATH_FILE="vocabulary.txt"
        TOKENS_PATH_FILE="tokens.txt"
        PROXIES_PATH_FILE="proxies.txt"
        PARSED_PATH_FILE="parsed.txt"
6. Пауза между отправкой сообщений - случайная из диапазона MIN_PAUSE-MAX_PAUSE секунд
7. У бота два режима:
   1. Брать фразы из готового файла и пользоваться ими для работы
    в основном чат
   2. Парсить MESSAGES_COUNT сообщений из другого чата, сохранять их в файл и пользоваться ими для работы
    в основном чате

8. Режим 1:
  Запрашиваем ссылку на сервер, в который будут писать токены. (должны быть добавлены на сервер)
  Загружаем список токенов из файла.
  Загружаем фразы.
  Загружаем прокси.
  Берем случайный токен из списка, случайную фразу и случайную прокси, пишем в основной канал.
  Выдерживаем паузу.
  Берем следующий токен... и так по кругу.
9. Режим 2:
  Запрашиваем ссылку на сервер, из которого будем парсить фразы
  (токен PARSING_TOKEN для парсинга должен быть добавлен на сервер)
  Берем токен для парсинга и парсим MESSAGES_COUNT сообщений и сохраняем их в файл parsed.txt.
10. Меню:
     1. Start from vocabulary.txt - берет фразы из файла vocabulary.txt и начинает работу
     2. Start from parsed.txt - берет фразы из файла parsed.txt и начинает работу
     3. Parsing from chat - Парсит MESSAGES_COUNT сообщений из заданного чата и добавляет их
     в файл parsed.txt.
     4. Set pause range - запрашивает диапазон для паузы

==> discord-chatbot-deskent-1.3.3.tar.gz: discord-chatbot-deskent-1.3.3/README.md <==
1. Установка и настройка:
    1. В файле .env нужно добавить токен от телеграм бота в поле
    TELEBOT_TOKEN="telegram_bot_token"

    2. свой ID телеграма в поле
    ADMIN="123456789"
    свой ID телеграма можно узнать в боте https://t.me/userinfobot

    3. и дискорд токен для парсинга в поле
    PARSING_TOKEN="discord_parsing_token"

2. Бот запускается командой python main.py локально или на сервере пользователя.
Для работы необходима версия python 3.8 или выше
3. Бот является телеграм-ботом, через который осуществляется запуск и управление.
4. Токены для дискорда хранятся в файле tokens.txt
5. Фразы хранятся в файле vocabulary.txt
   1. Прокси хранятся в файле proxies.txt в формате (user:password:address:port)
      В файле .env находятся настройки бота:
        TELEBOT_TOKEN="telegram_bot_token" - токен от телеграм бота, для управления
        MESSAGES_COUNT=1000 - количество сообщений для парсинга
        MIN_PAUSE=1 - минимальное значение для паузы между сообщениями
        MAX_PAUSE=3600 - максимальное значение для паузы между сообщениями
        ADMIN="123456789" - телеграм id пользователя, которому будет доступен телеграм бот
        PARSING_TOKEN="token_for_chat_parsing" - токен дискорда для парсинга фраз
        PHRASE_RANDOM=False - если True то берет случайную фразу из словаря, если False - по порядку
     Настройки для имен файлов:
        VOCABULARY_PATH_FILE="vocabulary.txt"
        TOKENS_PATH_FILE="tokens.txt"
        PROXIES_PATH_FILE="proxies.txt"
        PARSED_PATH_FILE="parsed.txt"
6. Пауза между отправкой сообщений - случайная из диапазона MIN_PAUSE-MAX_PAUSE секунд
7. У бота два режима:
   1. Брать фразы из готового файла и пользоваться ими для работы
    в основном чат
   2. Парсить MESSAGES_COUNT сообщений из другого чата, сохранять их в файл и пользоваться ими для работы
    в основном чате

8. Режим 1:
  Запрашиваем ссылку на сервер, в который будут писать токены. (должны быть добавлены на сервер)
  Загружаем список токенов из файла.
  Загружаем фразы.
  Загружаем прокси.
  Берем случайный токен из списка, случайную фразу и случайную прокси, пишем в основной канал.
  Выдерживаем паузу.
  Берем следующий токен... и так по кругу.
9. Режим 2:
  Запрашиваем ссылку на сервер, из которого будем парсить фразы
  (токен PARSING_TOKEN для парсинга должен быть добавлен на сервер)
  Берем токен для парсинга и парсим MESSAGES_COUNT сообщений и сохраняем их в файл parsed.txt.
10. Меню:
     1. Start from vocabulary.txt - берет фразы из файла vocabulary.txt и начинает работу
     2. Start from parsed.txt - берет фразы из файла parsed.txt и начинает работу
     3. Parsing from chat - Парсит MESSAGES_COUNT сообщений из заданного чата и добавляет их
     в файл parsed.txt.
     4. Set pause range - запрашивает диапазон для паузы
